@@ -34,12 +34,12 @@ class MINUETINTERFACES_EXPORT IPluginController : public QObject
     Q_OBJECT
 
 public:
-    virtual ~IPluginController() override;
+    ~IPluginController() override = default;
 
     virtual QString errorString() const = 0;
 
 protected:
-    explicit IPluginController(QObject *parent = 0);
+    explicit IPluginController(QObject *parent = nullptr);
 };
 
 }
